# Help classes

Sometimes properties have a lot in common. Instead of constantly redefining all methods, we simply create an abstraction from the properties which we call help classes.

This is the list of all help classes.

::: ical_library.ical_properties.ints._IntProperty

::: ical_library.ical_properties.dt._DTBoth

::: ical_library.ical_properties.dt._DTSingular

::: ical_library.ical_properties.cal_address._CalAddress

::: ical_library.ical_properties.periods._PeriodFunctionality

::: ical_library.ical_properties.periods._ExOrRDate

::: ical_library.ical_properties.tz_offset._TZOffset
